@@ -1,6 +1,6 @@
 /*
     This file is part of Android File Transfer For Linux.
-    Copyright (C) 2015-2018  Vladimir Menshakov
+    Copyright (C) 2015-2020  Vladimir Menshakov
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Lesser General Public License as published by
@@ -17,8 +17,8 @@
     Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
-#ifndef USB_CONTEXT_H
-#define USB_CONTEXT_H
+#ifndef AFTL_MTP_BACKEND_DARWIN_USB_CONTEXT_H
+#define AFTL_MTP_BACKEND_DARWIN_USB_CONTEXT_H
 
 #include <mtp/types.h>
 #include <usb/DeviceDescriptor.h>
